@@ -1,4 +1,4 @@
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 use std::convert::From;
 
 /***************************/
@@ -11,7 +11,7 @@ use std::convert::From;
 
 #[derive(Deserialize, Debug)]
 pub struct Config {
-    pub db_path: Option<String>,
+    pub db_url: Option<String>,
     pub scan_period: Option<u64>,
 
     // N3NX Network APIs Config
@@ -70,7 +70,39 @@ pub struct AllProjects {
     pub projects: Vec<Project>,
 }
 
-#[derive(Deserialize, Debug, Default, PartialEq)]
+#[derive(Deserialize, Debug, Default)]
+pub struct AllGithubRepos {
+    pub total_count: u32,
+    pub incomplete_results: bool,
+    pub items: Vec<GithubRepo>,
+}
+
+#[derive(Deserialize, Debug)]
+pub struct GithubRepo {
+    pub name: String,
+    pub description: String,
+    pub html_url: String,
+    pub url: String,
+    pub default_branch: String,
+    pub language: Option<String>,
+    pub is_template: bool,
+    pub stargazers_count: u32,
+    pub watchers_count: u32,
+    pub forks_count: u32,
+    pub archived: bool,
+    pub fork: bool,
+    pub size: u32,
+}
+
+#[derive(Debug)]
+pub struct ProjectMeta {
+    pub tags: Vec<String>,
+    pub featured: bool,
+    pub emoji: String,
+    pub template: bool,
+}
+
+#[derive(Deserialize, Debug, Default, PartialEq, Serialize)]
 pub struct Project {
     pub name: String,
     pub desc: String,
@@ -89,7 +121,14 @@ pub struct Changelog {
     pub data: String,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Serialize, Deserialize)]
+pub struct StatefulChangelog {
+    pub project_name: String,
+    pub hash: String,
+    pub prev_hash: String,
+}
+
+#[derive(Debug, Serialize, Deserialize)]
 pub struct Version {
     pub project_name: String,
     pub hash: String,
@@ -144,23 +183,3 @@ impl From<MediaId> for &str {
         }
     }
 }
-/***************************/
-/*-------------------------*/
-/*--                     --*/
-/*--    Reddit Models    --*/
-/*--                     --*/
-/*-------------------------*/
-/***************************/
-
-// #[derive(Debug, Serialize)]
-// pub struct RedditSend {
-//     pub flair_id: String,
-//     pub flair_text: String,
-//     pub kind: String,
-//     pub nsfw: bool,
-//     pub resubmit: bool,
-//     pub sr: String,
-//     pub title: String,
-//     pub text: String,
-//     pub url: String,
-// }
